#!/bin/python
# Pack a set of files onto CDs in a reasonably efficient way.
# Adam Sampson <azz@gnu.org>

import os, sys

cdsize = 700*1024*1024

# Get the size of each file.
size = {}
tsize = 0
for x in sys.argv[1:]:
	size[x] = os.stat(x).st_size
	tsize += size[x]

# Sort the files by size, largest first.
files = size.keys()
files.sort(lambda a, b: cmp(size[b], size[a]))

def fullness(disc):
	total = 0
	for file in disc: total += size[file]
	return total

# For each file, put it onto the first disc that it will fit onto.
discs = []
for x in files:
	s = size[x]
	found = 0
	for n in range(len(discs)):
		if fullness(discs[n]) + s <= cdsize:
			discs[n].append(x)
			found = 1
			break
	if not found: discs.append([x])

ndiscs = len(discs)
for n in range(ndiscs):
	d = discs[n]
	print "# Disc ", n, " contains ", fullness(d), " bytes"
	print "mkisofs -R -J -o /tmp/tmp.iso ", " ".join(map(lambda x: '"' + x + '"', d))

print "# Size of files: ", tsize
print "# Size of discs: ", (cdsize * ndiscs)
print "# Final efficiency: ", (1.0 * tsize) / (cdsize * ndiscs)

